/**
 * @file ntm.c
 * @author Shinichiro Nakamura
 * @brief NTMの実装。
 */

/*
 * ===============================================================
 *  Natural Tiny Monitor (NT-Monitor)
 * ===============================================================
 * Copyright (c) 2011-2012 Shinichiro Nakamura
 * Inspired by M, Murakami
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 * ===============================================================
 */

#include "ntm.h"
#include "ntmcmd.h"
#include "ntmlibc.h"

/**
 * @brief Natural Tiny Monitorを実行する。
 * @details この関数は永遠に処理を返さない。
 * @param ntmshell シェルオブジェクト。
 */
void ntm_execute(
    ntmshell_t *ntmshell,
    int (*serial_read)(char *buf, int cnt, void *extobj),
    int (*serial_write)(const char *buf, int cnt, void *extobj),
    void *extobj)
{
    ntmcmd_extobj_t eo;
    eo.serial_read = serial_read;
    eo.serial_write = serial_write;
    eo.user_extobj = extobj;

    ntmshell_init(
        ntmshell,
        serial_read,
        serial_write,
        ntmcmd_execute,
        (void *)&eo);

    /*
     * シェルを実行する。
     */
    while (1) {
        ntmshell_execute(ntmshell);
    }
}

