/**
 * @file ntmshell.h
 * @author Shinichiro Nakamura
 * @brief NTMシェルシステムの定義。
 */

/*
 * ===============================================================
 *  Natural Tiny Monitor (NT-Monitor)
 * ===============================================================
 * Copyright (c) 2011-2012 Shinichiro Nakamura
 * Inspired by M, Murakami
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 * ===============================================================
 */

#ifndef NTMSHELL_H
#define NTMSHELL_H

#include "ntmconf.h"

#if (NTMCONF_USE_NTSHELL == 1)

#   include "ntshell.h"
#   define ntmshell_t           ntshell_t
#   define ntmshell_init        ntshell_init
#   define ntmshell_execute     ntshell_execute
#   define ntmshell_set_prompt  ntshell_set_prompt
#   define ntmshell_version     ntshell_version

#else

typedef int (*NTMSHELL_SERIAL_READ)(char *buf, int cnt, void *extobj);
typedef int (*NTMSHELL_SERIAL_WRITE)(const char *buf, int cnt, void *extobj);
typedef int (*NTMSHELL_USER_CALLBACK)(const char *text, void *extobj);

    typedef struct {
        char prompt[32];
        char buf_curr[NTMCONF_EDITOR_MAXLEN];
        char buf_prev[NTMCONF_EDITOR_MAXLEN];
        int len;
        NTMSHELL_SERIAL_READ func_read;
        NTMSHELL_SERIAL_WRITE func_write;
        NTMSHELL_USER_CALLBACK func_callback;
        void *extobj;
    } ntmshell_t;

#ifdef __cplusplus
extern "C" {
#endif

    void ntmshell_init(ntmshell_t *p,
        NTMSHELL_SERIAL_READ func_read,
        NTMSHELL_SERIAL_WRITE func_write,
        NTMSHELL_USER_CALLBACK func_callback,
        void *extobj);
    void ntmshell_execute(ntmshell_t *p);
    void ntmshell_set_prompt(ntmshell_t *p, const char *prompt);
    void ntmshell_version(int *major, int *minor, int *release);

#ifdef __cplusplus
}
#endif

#endif

#endif

